gchecky.model.charge_amount_notification_t

Package gchecky :: Module model :: Class charge_amount_notification_t |
[hide private]
[frames] | no frames]

# Class charge_amount_notification_t

source code

         object --+
                  |
          gxml.Node --+
                      |
          gxml.Document --+
                          |
    abstract_notification_t --+
                              |
                             charge_amount_notification_t

Represents information about a successful charge for an order.

    >>> from datetime import datetime
    >>> import iso8601
    >>> test_document(
    ...     charge_amount_notification_t(
    ...         serial_number='95d44287-12b1-4722-bc56-cfaa73f4c0d1',
    ...         google_order_number = '841171949013218',
    ...         timestamp = iso8601.parse_date('2006-03-18T18:25:31.593Z'),
    ...         latest_charge_amount = price_t(currency='USD', value=2226.06),
    ...         total_charge_amount = price_t(currency='USD', value=2226.06)
    ...     )
    ... ,
    ...     '''
    ...     <charge-amount-notification xmlns="http://checkout.google.com/schema/2" serial-number="95d44287-12b1-4722-bc56-cfaa73f4c0d1">
    ...       <latest-charge-amount currency="USD">2226.060</latest-charge-amount>
    ...       <google-order-number>841171949013218</google-order-number>
    ...       <total-charge-amount currency="USD">2226.060</total-charge-amount>
    ...       <timestamp>2006-03-18T18:25:31.593000+00:00</timestamp>
    ...     </charge-amount-notification>
    ...     '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``charge-amount-notification``'`` The document's unique xml tag name.
| latest_charge_amount = `Node:PATH(latest-charge-amount):REQ:{ p`...``
| total_charge_amount = `Node:PATH(total-charge-amount):REQ:{ pri`...``
| _fields = ``{``'``google_order_number``'``:` ID:PATH(google-order-number)`...`` list of meta-Fields of this class.
Inherited from `abstract_notification_t`: `google_order_number`, `serial_number`, `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### latest_charge_amount Value:
      Node:PATH(latest-charge-amount):REQ:{ price_t }

  ### total_charge_amount Value:
      Node:PATH(total-charge-amount):REQ:{ price_t }

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(google-order-number):REQ,
       'latest_charge_amount': Node:PATH(latest-charge-amount):REQ:{ price_t
       },
       'serial_number': ID:PATH(@serial-number):REQ,
       'timestamp': Timestamp:PATH(timestamp):REQ,
       'total_charge_amount': Node:PATH(total-charge-amount):REQ:{ price_t }
      }